@@ -1,8 +1,11 @@
 from .from_binding_provider_factory import FromBindingProviderFactory
 from .from_cache_provider_factory import FromCacheProviderFactory
-from .union_provider_factory import UnionProviderFactory
+from .from_env_var_provider_factory import FromEnvVarProviderFactory
+from .jit_provider_factory import JitProviderFactory
+from .list_provider_factory import ListProviderFactory
 from .provider_factory import ProviderFactory
 from .provider_provider_factory import ProviderProviderFactory
 from .set_provider_factory import SetProviderFactory
 from .tuple_provider_factory import TupleProviderFactory
 from .type_provider_factory import TypeProviderFactory
+from .union_provider_factory import UnionProviderFactory
